parse_fence_open

Function parse_fence_open 

fn parse_fence_open(line: &str) -> Option<FenceOpen>
Recognise the opening of a fenced code block on this line. CommonMark allows up to 3 leading spaces before the fence run. Returns the fence shape if line is a valid open fence.