flatten_registry_in_source_order

Function flatten_registry_in_source_order 

pub(crate) fn flatten_registry_in_source_order<'a>(
    lex_out: &BorrowedLexOutput<'a>,
) -> Vec<NodeRef<'a>>
Walk lex_out.normalized byte-by-byte; for every PUA sentinel, query the registry and append the resulting [NodeRef] to a freshly-allocated Vec in source order.

Returns an empty vec when the registry is empty (the typical branch when Options::aozora_enabled is false).