fn parse_fence_open(line: &str) -> Option<FenceOpen>Expand description
Recognise the opening of a fenced code block on this line.
CommonMark allows up to 3 leading spaces before the fence run.
Returns the fence shape if line is a valid open fence.